@@ -1,4 +1,4 @@
-# All Rights Reserved.
+#  Copyright 2018-Present The CloudEvents Authors
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -26,9 +26,7 @@ class CloudEvent:
     Supports both binary and structured mode CloudEvents
     """
 
-    def __init__(
-        self, attributes: typing.Dict[str, str], data: typing.Any = None
-    ):
+    def __init__(self, attributes: typing.Dict[str, str], data: typing.Any = None):
         """
         Event Constructor
         :param attributes: a dict with cloudevent attributes. Minimally
@@ -69,28 +67,46 @@ class CloudEvent:
                 f"Missing required keys: {required_set - self._attributes.keys()}"
             )
 
-    def __eq__(self, other):
-        return self.data == other.data and self._attributes == other._attributes
+    def __eq__(self, other: typing.Any) -> bool:
+        if isinstance(other, CloudEvent):
+            return self.data == other.data and self._attributes == other._attributes
+        return False
 
     # Data access is handled via `.data` member
     # Attribute access is managed via Mapping type
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> typing.Any:
         return self._attributes[key]
 
-    def __setitem__(self, key, value):
+    def get(
+        self, key: str, default: typing.Optional[typing.Any] = None
+    ) -> typing.Optional[typing.Any]:
+        """
+        Retrieves an event attribute value for the given key.
+        Returns the default value if not attribute for the given key exists.
+
+        MUST NOT throw an exception when the key does not exist.
+
+        :param key: The event attribute name.
+        :param default: The default value to be returned when
+            no attribute with the given key exists.
+        :returns: The event attribute value if exists, default value otherwise.
+        """
+        return self._attributes.get(key, default)
+
+    def __setitem__(self, key: str, value: typing.Any) -> None:
         self._attributes[key] = value
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: str) -> None:
         del self._attributes[key]
 
-    def __iter__(self):
+    def __iter__(self) -> typing.Iterator[typing.Any]:
         return iter(self._attributes)
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._attributes)
 
-    def __contains__(self, key):
+    def __contains__(self, key: str) -> bool:
         return key in self._attributes
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return str({"attributes": self._attributes, "data": self.data})
