@@ -1,3 +1,17 @@
+#  Copyright 2018-Present The CloudEvents Authors
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 import typing
 
 from cloudevents.sdk.converters import binary, structured
@@ -26,6 +40,4 @@ def is_structured(headers: typing.Dict[str, str]) -> bool:
     headers = {key.lower(): value for key, value in headers.items()}
     content_type = headers.get("content-type", "")
     structured_parser = structured.JSONHTTPCloudEventConverter()
-    return structured_parser.can_read(
-        content_type=content_type, headers=headers
-    )
+    return structured_parser.can_read(content_type=content_type, headers=headers)
