@@ -1,4 +1,4 @@
-# All Rights Reserved.
+#  Copyright 2018-Present The CloudEvents Authors
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -26,9 +26,7 @@ class JSONHTTPCloudEventConverter(base.Converter):
     TYPE = "structured"
     MIME_TYPE = "application/cloudevents+json"
 
-    def can_read(
-        self, content_type: str, headers: typing.Dict[str, str] = {}
-    ) -> bool:
+    def can_read(self, content_type: str, headers: typing.Dict[str, str] = {}) -> bool:
         return (
             isinstance(content_type, str)
             and content_type.startswith(self.MIME_TYPE)
